[Libreoffice-commits] core.git: 4 commits - cli_ure/source dtrans/source fpicker/source shell/inc shell/source

Stephan Bergmann sbergman at redhat.com
Thu Oct 2 06:21:26 PDT 2014


 cli_ure/source/uno_bridge/cli_base.h                              |    6 +--
 cli_ure/source/uno_bridge/cli_data.cxx                            |   16 +++++-----
 cli_ure/source/uno_bridge/cli_uno.cxx                             |    2 -
 dtrans/source/win32/clipb/WinClipboard.hxx                        |    2 -
 fpicker/source/win32/filepicker/FilePicker.cxx                    |    4 +-
 fpicker/source/win32/filepicker/FilePicker.hxx                    |    2 -
 fpicker/source/win32/filepicker/PreviewCtrl.hxx                   |    4 +-
 fpicker/source/win32/filepicker/WinFileOpenImpl.hxx               |    8 ++---
 fpicker/source/win32/filepicker/asynceventnotifier.cxx            |    2 -
 fpicker/source/win32/filepicker/controlcommand.hxx                |    2 -
 fpicker/source/win32/filepicker/previewadapter.cxx                |    2 -
 fpicker/source/win32/filepicker/previewadapter.hxx                |    2 -
 fpicker/source/win32/folderpicker/FolderPicker.cxx                |    2 -
 fpicker/source/win32/folderpicker/FolderPicker.hxx                |    2 -
 shell/inc/internal/zipfile.hxx                                    |    2 -
 shell/source/win32/shlxthandler/propsheets/document_statistic.hxx |    2 -
 shell/source/win32/shlxthandler/propsheets/listviewbuilder.hxx    |    2 -
 shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx       |    2 -
 18 files changed, 32 insertions(+), 32 deletions(-)

New commits:
commit 36d24bced0ea5fcbbd380b15e9d1a813fbef32cf
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Thu Oct 2 15:20:54 2014 +0200

    shell (Windows): std::auto_ptr -> std::unique_ptr
    
    Change-Id: I44c843c028c2dfcfcea9f6a2196440ca700fc3a8

diff --git a/shell/inc/internal/zipfile.hxx b/shell/inc/internal/zipfile.hxx
index 15a9001..a2e369c 100644
--- a/shell/inc/internal/zipfile.hxx
+++ b/shell/inc/internal/zipfile.hxx
@@ -40,7 +40,7 @@ class ZipFile
 public:
 
     typedef std::vector<std::string>   Directory_t;
-    typedef std::auto_ptr<Directory_t> DirectoryPtr_t;
+    typedef std::unique_ptr<Directory_t> DirectoryPtr_t;
     typedef std::vector<char>          ZipContentBuffer_t;
 
 public:
diff --git a/shell/source/win32/shlxthandler/propsheets/document_statistic.hxx b/shell/source/win32/shlxthandler/propsheets/document_statistic.hxx
index 1216f4a..45a7477 100644
--- a/shell/source/win32/shlxthandler/propsheets/document_statistic.hxx
+++ b/shell/source/win32/shlxthandler/propsheets/document_statistic.hxx
@@ -55,7 +55,7 @@ typedef std::vector<statistic_group_t>                  statistic_group_list_t;
 
 
 class document_statistic_reader;
-typedef std::auto_ptr<document_statistic_reader> document_statistic_reader_ptr;
+typedef std::unique_ptr<document_statistic_reader> document_statistic_reader_ptr;
 
 document_statistic_reader_ptr create_document_statistic_reader(const std::string& document_name, CMetaInfoReader* meta_info_accessor);
 
diff --git a/shell/source/win32/shlxthandler/propsheets/listviewbuilder.hxx b/shell/source/win32/shlxthandler/propsheets/listviewbuilder.hxx
index 68078f0..870c33c 100644
--- a/shell/source/win32/shlxthandler/propsheets/listviewbuilder.hxx
+++ b/shell/source/win32/shlxthandler/propsheets/listviewbuilder.hxx
@@ -35,7 +35,7 @@
 
 
 class list_view_builder;
-typedef std::auto_ptr<list_view_builder> list_view_builder_ptr;
+typedef std::unique_ptr<list_view_builder> list_view_builder_ptr;
 
 // factory method for list_view_builder
 list_view_builder_ptr create_list_view_builder(
diff --git a/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx b/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
index 45918f5..8c62836 100644
--- a/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
+++ b/shell/source/win32/shlxthandler/thumbviewer/thumbviewer.cxx
@@ -357,7 +357,7 @@ HRESULT STDMETHODCALLTYPE CThumbviewer::Extract(HBITMAP *phBmpImage)
     try
     {
         std::wstring fname = getShortPathName( filename_ );
-        std::auto_ptr<ZipFile> zipfile( new ZipFile( WStringToString( fname ) ) );
+        std::unique_ptr<ZipFile> zipfile( new ZipFile( WStringToString( fname ) ) );
 
         if (zipfile->HasContent(THUMBNAIL_CONTENT))
         {
commit fb515368bd8200b4d279061bf2b6bd8b38c27a2e
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Thu Oct 2 15:20:46 2014 +0200

    fpicker (Windows): std::auto_ptr -> std::unique_ptr
    
    Change-Id: Id373c3ed6e483a501e07146812ff04353eafcc32

diff --git a/fpicker/source/win32/filepicker/FilePicker.cxx b/fpicker/source/win32/filepicker/FilePicker.cxx
index 8e68036..2e7cda5 100644
--- a/fpicker/source/win32/filepicker/FilePicker.cxx
+++ b/fpicker/source/win32/filepicker/FilePicker.cxx
@@ -76,7 +76,7 @@ CFilePicker::CFilePicker( const uno::Reference<lang::XMultiServiceFactory>& xSer
     SAL_WARN_IF( !hInstance, "fpicker", "The name of the service dll must have changed" );
 
     // create a default FileOpen dialog without any additional ui elements
-    m_pImpl = std::auto_ptr< CWinFileOpenImpl >(
+    m_pImpl = std::unique_ptr< CWinFileOpenImpl >(
         new CWinFileOpenImpl(
             this,
             true,
@@ -682,7 +682,7 @@ void SAL_CALL CFilePicker::initialize(const uno::Sequence<uno::Any>& aArguments)
     // create a new impl-class here based on the
     // given string, if the given string is empty
     // we do nothing
-    m_pImpl = std::auto_ptr< CWinFileOpenImpl >(
+    m_pImpl = std::unique_ptr< CWinFileOpenImpl >(
         new CWinFileOpenImpl(
             this,
             bFileOpenDialog,
diff --git a/fpicker/source/win32/filepicker/FilePicker.hxx b/fpicker/source/win32/filepicker/FilePicker.hxx
index 9aee615..925d466 100644
--- a/fpicker/source/win32/filepicker/FilePicker.hxx
+++ b/fpicker/source/win32/filepicker/FilePicker.hxx
@@ -231,7 +231,7 @@ private:
 private:
     ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > m_xServiceMgr;   // to instanciate own services
     CAsyncEventNotifier                                                            m_aAsyncEventNotifier;
-    std::auto_ptr<CWinFileOpenImpl>                                                m_pImpl;
+    std::unique_ptr<CWinFileOpenImpl>                                                m_pImpl;
 };
 
 #endif
diff --git a/fpicker/source/win32/filepicker/WinFileOpenImpl.hxx b/fpicker/source/win32/filepicker/WinFileOpenImpl.hxx
index 3383b89..dd9a4c2 100644
--- a/fpicker/source/win32/filepicker/WinFileOpenImpl.hxx
+++ b/fpicker/source/win32/filepicker/WinFileOpenImpl.hxx
@@ -197,10 +197,10 @@ private:
     static BOOL CALLBACK EnumChildWndProc( HWND hWnd, LPARAM lParam );
 
 private:
-    std::auto_ptr<CFilterContainer>         m_filterContainer;
-    std::auto_ptr<CPreviewAdapter>          m_Preview;
-    std::auto_ptr<CCustomControlFactory>    m_CustomControlFactory;
-    std::auto_ptr<CCustomControl>           m_CustomControls;
+    std::unique_ptr<CFilterContainer>       m_filterContainer;
+    std::unique_ptr<CPreviewAdapter>        m_Preview;
+    std::unique_ptr<CCustomControlFactory>  m_CustomControlFactory;
+    std::unique_ptr<CCustomControl>         m_CustomControls;
     CFilePicker*                            m_FilePicker;
     WNDPROC                                 m_pfnOldDlgProc;
     OUString                           m_defaultName;
diff --git a/fpicker/source/win32/filepicker/asynceventnotifier.cxx b/fpicker/source/win32/filepicker/asynceventnotifier.cxx
index b7df994..f9cdd88 100644
--- a/fpicker/source/win32/filepicker/asynceventnotifier.cxx
+++ b/fpicker/source/win32/filepicker/asynceventnotifier.cxx
@@ -260,7 +260,7 @@ void SAL_CALL CAsyncEventNotifier::run()
         {
             while (getEventListSize() > 0)
             {
-                std::auto_ptr<CEventNotification> EventNotification(getNextEventRecord());
+                std::unique_ptr<CEventNotification> EventNotification(getNextEventRecord());
                 removeNextEventRecord();
 
                 ::cppu::OInterfaceContainerHelper* pICHelper =
diff --git a/fpicker/source/win32/filepicker/controlcommand.hxx b/fpicker/source/win32/filepicker/controlcommand.hxx
index ae63ff8..b1d20d3 100644
--- a/fpicker/source/win32/filepicker/controlcommand.hxx
+++ b/fpicker/source/win32/filepicker/controlcommand.hxx
@@ -46,7 +46,7 @@ public:
 
     // the client inherits the ownership of the returned
     // CControlCommandResult and has to delete it or he may
-    // use the auto_ptr template for automatic deletion
+    // use the unique_ptr template for automatic deletion
     virtual CControlCommandResult* SAL_CALL handleRequest( CControlCommandRequest* aRequest );
 
     // clients of this method should use the returned
diff --git a/fpicker/source/win32/filepicker/previewadapter.cxx b/fpicker/source/win32/filepicker/previewadapter.cxx
index df66893..380750e 100644
--- a/fpicker/source/win32/filepicker/previewadapter.cxx
+++ b/fpicker/source/win32/filepicker/previewadapter.cxx
@@ -86,7 +86,7 @@ protected:
 // member
 protected:
     HINSTANCE                   m_Instance;
-    std::auto_ptr<PreviewBase>  m_Preview;
+    std::unique_ptr<PreviewBase> m_Preview;
     HWND                        m_FileDialog;
     int                         m_RightMargin;
 
diff --git a/fpicker/source/win32/filepicker/previewadapter.hxx b/fpicker/source/win32/filepicker/previewadapter.hxx
index fc05fa0..dc40889 100644
--- a/fpicker/source/win32/filepicker/previewadapter.hxx
+++ b/fpicker/source/win32/filepicker/previewadapter.hxx
@@ -87,7 +87,7 @@ public:
 private:
     // hide implementation details using the
     // bridge pattern
-    std::auto_ptr<CPreviewAdapterImpl> m_pImpl;
+    std::unique_ptr<CPreviewAdapterImpl> m_pImpl;
 
 // prevent copy and assignment
 private:
diff --git a/fpicker/source/win32/folderpicker/FolderPicker.cxx b/fpicker/source/win32/folderpicker/FolderPicker.cxx
index edf2698..9bc256e 100644
--- a/fpicker/source/win32/folderpicker/FolderPicker.cxx
+++ b/fpicker/source/win32/folderpicker/FolderPicker.cxx
@@ -64,7 +64,7 @@ namespace
 CFolderPicker::CFolderPicker( const Reference< XMultiServiceFactory >& xServiceMgr ) :
     m_xServiceMgr( xServiceMgr )
 {
-    m_pFolderPickerImpl = std::auto_ptr< CWinFolderPickerImpl > ( new CWinFolderPickerImpl( this ) );
+    m_pFolderPickerImpl = std::unique_ptr< CWinFolderPickerImpl > ( new CWinFolderPickerImpl( this ) );
 }
 
 
diff --git a/fpicker/source/win32/folderpicker/FolderPicker.hxx b/fpicker/source/win32/folderpicker/FolderPicker.hxx
index 721ad68..400ade0 100644
--- a/fpicker/source/win32/folderpicker/FolderPicker.hxx
+++ b/fpicker/source/win32/folderpicker/FolderPicker.hxx
@@ -99,7 +99,7 @@ public:
 
 private:
     com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory > m_xServiceMgr;
-    std::auto_ptr< CWinFolderPickerImpl >   m_pFolderPickerImpl;
+    std::unique_ptr< CWinFolderPickerImpl >   m_pFolderPickerImpl;
     osl::Mutex  m_aMutex;
 
 // prevent copy and assignment
commit a5e521491b1b4e50cb2df1aa7c2895aeff6ca461
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Thu Oct 2 15:20:35 2014 +0200

    dtrans (Windows): std::auto_ptr -> std::unique_ptr
    
    Change-Id: Ia668873e93be100d6e6bbebbad94b369f75c702a

diff --git a/dtrans/source/win32/clipb/WinClipboard.hxx b/dtrans/source/win32/clipb/WinClipboard.hxx
index 8e6f662..0ef12f0 100644
--- a/dtrans/source/win32/clipb/WinClipboard.hxx
+++ b/dtrans/source/win32/clipb/WinClipboard.hxx
@@ -120,7 +120,7 @@ private:
     void SAL_CALL notifyAllClipboardListener( );
 
 private:
-    ::std::auto_ptr< CWinClipbImpl >                                              m_pImpl;
+    ::std::unique_ptr< CWinClipbImpl >                                            m_pImpl;
     ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >  m_xContext;
 
     friend class CWinClipbImpl;
commit 04740cb7e23cc293e1143d6dc7a4444202331abb
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Thu Oct 2 15:20:26 2014 +0200

    cli_ure (Windows): std::auto_ptr -> std::unique_ptr
    
    Change-Id: Ibe794daffa347d194ff8c66a44c7eec4bcc9b83d

diff --git a/cli_ure/source/uno_bridge/cli_base.h b/cli_ure/source/uno_bridge/cli_base.h
index ebe00c2..47aa720 100644
--- a/cli_ure/source/uno_bridge/cli_base.h
+++ b/cli_ure/source/uno_bridge/cli_base.h
@@ -124,15 +124,15 @@ struct rtl_mem
     inline static void operator delete ( void *, void * )
         {}
 
-    static inline ::std::auto_ptr< rtl_mem > allocate( ::std::size_t bytes );
+    static inline ::std::unique_ptr< rtl_mem > allocate( ::std::size_t bytes );
 };
 
-inline ::std::auto_ptr< rtl_mem > rtl_mem::allocate( ::std::size_t bytes )
+inline ::std::unique_ptr< rtl_mem > rtl_mem::allocate( ::std::size_t bytes )
 {
     void * p = rtl_allocateMemory( bytes );
     if (0 == p)
         throw BridgeRuntimeError("out of memory!" );
-    return ::std::auto_ptr< rtl_mem >( (rtl_mem *)p );
+    return ::std::unique_ptr< rtl_mem >( (rtl_mem *)p );
 }
 
 
diff --git a/cli_ure/source/uno_bridge/cli_data.cxx b/cli_ure/source/uno_bridge/cli_data.cxx
index f050ee0..2012443 100644
--- a/cli_ure/source/uno_bridge/cli_data.cxx
+++ b/cli_ure/source/uno_bridge/cli_data.cxx
@@ -49,9 +49,9 @@ OUString mapCliTypeName(System::String^ typeName);
 System::String^ mapCliPolymorphicName(System::String^ unoName);
 System::String^ mapPolymorphicName(System::String^ unoName, bool bCliToUno);
 
-inline auto_ptr< rtl_mem > seq_allocate( sal_Int32 nElements, sal_Int32 nSize )
+inline unique_ptr< rtl_mem > seq_allocate( sal_Int32 nElements, sal_Int32 nSize )
 {
-    auto_ptr< rtl_mem > seq(
+    unique_ptr< rtl_mem > seq(
         rtl_mem::allocate( SAL_SEQUENCE_HEADER_SIZE + (nElements * nSize) ) );
     uno_Sequence * p = (uno_Sequence *)seq.get();
     p->nRefCount = 1;
@@ -897,7 +897,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_Int64) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_Int64) ) );
                         *(sal_Int64 *) mem.get()=  *safe_cast<System::Int64^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -910,7 +910,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_uInt64) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (sal_uInt64) ) );
                         *(sal_uInt64 *) mem.get()=  *safe_cast<System::UInt64^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -923,7 +923,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (float) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (float) ) );
                         *(float*) mem.get() = *safe_cast<System::Single^>(aAny.Value);
                         pAny->pData = mem.release();
                     }
@@ -936,7 +936,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     }
                     else
                     {
-                        auto_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (double) ) );
+                        unique_ptr< rtl_mem > mem( rtl_mem::allocate( sizeof (double) ) );
                         *(double*) mem.get()= *safe_cast<System::Double^>(aAny.Value);
                         pAny->pData= mem.release();
                     }
@@ -965,7 +965,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                     css::uno::Type anyType(value_td);
                     typelib_TypeDescription* td= NULL;
                     anyType.getDescription(&td);
-                    auto_ptr< rtl_mem > mem(rtl_mem::allocate(td->nSize));
+                    unique_ptr< rtl_mem > mem(rtl_mem::allocate(td->nSize));
                     typelib_typedescription_release(td);
                     map_to_uno(
                         mem.get(), aAny.Value, value_td.getTypeLibType(),
@@ -1238,7 +1238,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
             typelib_TypeDescriptionReference * element_type =
                 ((typelib_IndirectTypeDescription *)td.get())->pType;
 
-            auto_ptr< rtl_mem > seq;
+            unique_ptr< rtl_mem > seq;
 
             System::Array^ ar = nullptr;
             if (cli_data != nullptr)
diff --git a/cli_ure/source/uno_bridge/cli_uno.cxx b/cli_ure/source/uno_bridge/cli_uno.cxx
index e705de1..97b0fa0 100644
--- a/cli_ure/source/uno_bridge/cli_uno.cxx
+++ b/cli_ure/source/uno_bridge/cli_uno.cxx
@@ -221,7 +221,7 @@ void Bridge::call_cli(
         System::Exception^ exc= e->InnerException;
         css::uno::TypeDescription td(mapCliType(exc->GetType()));
         // memory for exception
-        std::auto_ptr< rtl_mem > memExc(rtl_mem::allocate(td.get()->nSize));
+        std::unique_ptr< rtl_mem > memExc(rtl_mem::allocate(td.get()->nSize));
         map_to_uno(memExc.get(), exc, td.get()->pWeakRef, false);
         (*uno_exc)->pType= td.get()->pWeakRef;
         (*uno_exc)->pData= memExc.release();


More information about the Libreoffice-commits mailing list
diff --git a/fpicker/source/win32/filepicker/PreviewCtrl.hxx b/fpicker/source/win32/filepicker/PreviewCtrl.hxx
index e826e54..0b4db89 100644
--- a/fpicker/source/win32/filepicker/PreviewCtrl.hxx
+++ b/fpicker/source/win32/filepicker/PreviewCtrl.hxx
@@ -156,8 +156,8 @@ protected:
     // singleton instance of this class
     virtual ~CFilePreview( );
 
-    // we use the stl auto_ptr class as singleton destroyer
-    typedef std::auto_ptr< CFilePreview > FILEPREVIEW_SINGLETON_DESTROYER_T;
+    // we use the stl unique_ptr class as singleton destroyer
+    typedef std::unique_ptr< CFilePreview > FILEPREVIEW_SINGLETON_DESTROYER_T;
 
 protected:
     virtual void SAL_CALL onPaint( HWND hWnd, HDC hDC );